
#ifndef KAAZING_WEBSOCKET_H_
#define KAAZING_WEBSOCKET_H_

#include "websocket.h"

// kaazing addon functions to websocket

/** @file */

/**
* kaazing_challenge_handler_t struct.
* the kaazing_challenge_handler_t struct is used during authentication when connect to kaazing gateway.
*/
typedef struct kaazing_challenge_handler_t_stct kaazing_challenge_handler_t;
struct kaazing_challenge_handler_t_stct{
	int (*canhandle_callback)(kaazing_challenge_handler_t* self, const char* challenge);    /**< canhandle_callback callback function when challenge received. 1 - this handler can handle the security challenge, 0 - this handler cannot handle the challenge. */
	char* (*handle_callback)(kaazing_challenge_handler_t* self, const char* challenge);     /**< handle_callback callback function when challenge received. returns a NULL terminated string that contains the Authorization for security challenge, or NULL for give up the challenge */
	void* parent;    /**< parent pointer to the customer's challenge handler object */
};

/**
 * websocket_set_challenge_handler Sets the challenge handler for the WebSocket connection.
 * this function sets the client's challenge handler that is used during authentication
 * both at the connect-time as well as at subsequent revalidation-time that
 * occurs at regular intervals.. client should call this function before calling websocket_connect()
 * @param ws pointer of websocket_t object
 * @param handler point to the kaazing_challenge_handler_t
 * @return int 0 - success, 1 - failed
 */
int websocket_set_challenge_handler(websocket_t* ws, kaazing_challenge_handler_t* handler);

/**
 * websocket_get_challenge_handler Gets the challenge handler for the WebSocket connection.
 * this function returns the client's challenge handler.
 * @param ws pointer of websocket_t object
 * @return handler point to the kaazing_challenge_handler_t
 */
kaazing_challenge_handler_t* websocket_get_challenge_handler(websocket_t* ws);

// kaazing default basic handler functions

/**
* credential_t struct.
* the credential_t struct is used to store username and password. It is return value of kaazing_basic_challenge_handler.
*/
typedef struct credential_t_stct {
	char* username;    /**< username NULL terminated string contains username */
	char* password;    /**< password NULL terminated string contains password */
}credential_t;


/**
* kaazing_basic_challengehandler_t struct.
* the kaazing ships with a default_challenge_handler_t to handle http "Basic" and kaazing "Application Basic" authentication.
*/
typedef struct kaazing_basic_challengehandler_t_stct {
	kaazing_challenge_handler_t* challenge_handler;    /**< challenge_handler pointer to the basic challenge handler object */
	credential_t* (*getcredential_callback)(const char* challenge);  /**< getcredential_callback pointer to callback function to get user's credentials */
}kaazing_basic_challengehandler_t;

/**
 * kaazing_basic_challenge_handler_new Creates a kaazing basic challenge handler object.
 * Clients can call this function to create a kaazing basic challenge handler object. NOTE: client should call this function before start the connection.
 * @param getcredential_callback point to callback function to get user's credentials
 * @return kaazing_challenge_handler_t object
 */
kaazing_challenge_handler_t* kaazing_basic_challenge_handler_new(credential_t* (*getcredential_callback)(const char* challenge));

#endif /* KAAZING_WEBSOCKET_H_ */
