<?xml version="1.0" encoding="UTF-8"?>
<!--

    Copyright (c) 2007-2014, Kaazing Corporation. All rights reserved.

-->

<!-- 
    Pre-parse transformation for gateway-config.xml files. 
    Adds xsi:type to login-module and service elements. 
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:output encoding="UTF-8" method="xml" omit-xml-declaration="no" />
    
    <!--
        Copy content over unmodified except for &lt;login-module&gt; and
        &lt;service&gt; elements.
    -->
    <xsl:template match="*[local-name()!='login-module' and local-name()!='service']|@*|text()|comment()|processing-instruction()">
        <xsl:copy>
            <xsl:apply-templates/>
        </xsl:copy>
    </xsl:template>

    <!-- Add xsi:type to &lt;login-module&gt;. -->
    <xsl:template match="*[local-name()='login-module']">
        <xsl:copy>
            <xsl:attribute name="xsi:type" namespace="http://www.w3.org/2001/XMLSchema-instance">
                <xsl:choose>
                    <xsl:when test="starts-with(./*[local-name()='type'],'class:')">CustomLoginModuleType</xsl:when>
                    <xsl:otherwise><xsl:value-of select="normalize-space(./*[local-name()='type'])" />LoginModuleType</xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates/>
        </xsl:copy>
    </xsl:template>

    <!--
        Add xsi:type to &lt;service&gt;. The name of the xsi:type is derived
        from the &lt;type&gt; of the &lt;service&gt; so that the stylesheet can
        be used for any type of service.
    -->
    <xsl:template match="*[local-name()='service']">
        <xsl:copy>
            <xsl:attribute name="xsi:type" namespace="http://www.w3.org/2001/XMLSchema-instance">
                <xsl:choose>
                    <xsl:when test="starts-with(./*[local-name()='type'],'$')">InternalServiceType</xsl:when>
                    <xsl:otherwise><xsl:value-of select="normalize-space(./*[local-name()='type'])" />ServiceType</xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>

</xsl:stylesheet>
