/**
 * Copyright (c) 2007-2012, Kaazing Corporation. All rights reserved.
 */

package com.kaazing.gateway.client;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArrayString;

final class WebSocketJSPeer extends JavaScriptObject {

    /**
     * Creates a new WebSocket JavaScript peer instance
     */
    protected WebSocketJSPeer() {
    }
    
    public static WebSocketJSPeer create(WebSocket proxy, String URL, String[] protocols) throws WebSocketException {
        JsArrayString protocolJsArray = null;
        if (protocols != null) {
            protocolJsArray = JavaScriptObject.createArray().cast();
            for (int i = 0; i < protocols.length; i++) {
                protocolJsArray.push(protocols[i]);
            }
        }
        return create(proxy, URL, protocolJsArray);
    }
    
    protected static native WebSocketJSPeer create(WebSocket proxy, String URL, JsArrayString protocols) throws WebSocketException /*-{
        var $this;
        try {
            if (protocols === null || protocols === undefined) {
                $this = new $wnd.WebSocket(URL);
            }
            else {
                $this = new $wnd.WebSocket(URL, protocols);
            }
        } catch (e) {
            throw new @com.kaazing.gateway.client.WebSocketException::new(Ljava/lang/String;)(e.message);
        }
    
        $this.onopen = function (headers) {
            proxy.@com.kaazing.gateway.client.WebSocket::handleOpen()
                 ();
        }
        $this.onmessage = function (event) {
            proxy.@com.kaazing.gateway.client.WebSocket::handleMessage(Lcom/kaazing/gateway/client/NativeMessageEvent;)
                 (event);
        }
        $this.onclose = function (event) {
            proxy.@com.kaazing.gateway.client.WebSocket::handleClose(Lcom/kaazing/gateway/client/NativeCloseEvent;)
                 (event);
        }
        $this.onerror = function (event) {
            proxy.@com.kaazing.gateway.client.WebSocket::handleError()
                ();
        }

        return $this;
    }-*/;


    protected static native WebSocketJSPeer createWebSocket(WebSocket proxy, WebSocketFactory factory, String URL, String[] protocol) throws WebSocketException /*-{
    var $this;
    try {
    	if (protocol === null || protocol === undefined) {
			$this = factory.createWebSocket(URL);
       	}
		else {
			$this = factory.createWebSocket(URL, protocol);
        }
    } catch (e) {
        throw new @com.kaazing.gateway.client.WebSocketException::new(Ljava/lang/String;)(e.message);
    }

    $this.onopen = function (headers) {
        proxy.@com.kaazing.gateway.client.WebSocket::handleOpen()
             ();
    }
    $this.onmessage = function (event) {
        proxy.@com.kaazing.gateway.client.WebSocket::handleMessage(Lcom/kaazing/gateway/client/NativeMessageEvent;)
             (event);
    }
    $this.onclose = function (event) {
        proxy.@com.kaazing.gateway.client.WebSocket::handleClose(Lcom/kaazing/gateway/client/NativeCloseEvent;)
             (event);
    }
    $this.onerror = function (event) {
        proxy.@com.kaazing.gateway.client.WebSocket::handleError()
             ();
    }

    return $this;
}-*/;
    
    /**
     * The URL with which the WebSocket was constructed.
     */
    protected native String getURL() /*-{
    	return this.URL;
    }-*/;


    /**
     * The ready state indicates the connection status.
     */
    protected native int getReadyState() /*-{
    	return this.readyState;
    }-*/;

    /**
     * The number of bytes queued to be sent.
     */
    protected native int getBufferedAmount() /*-{
    	return this.bufferedAmount;
    }-*/;
    
    /**
     * The BinaryType of the WebSocket
     * valid values: "bytebuffer", "arraybuffer" and "blob"
     */
    public native String binaryType() /*-{
    	return this.binaryType;
    }-*/;
    public native void binaryType(String newBinaryType) /*-{
    	if(typeof(WebSocketFactory) == "function" || newBinaryType != "bytebuffer" ) {
			this.binaryType = newBinaryType;
    	}
    	else {
    		this.binaryType = "arraybuffer";
    	}
    	
	}-*/;
    
    /**
     * Disconnects the remote socket location.
     *
     * @return {void}
     *
     * @public
     * @function
     * @name close
     * @memberOf WebSocket
     */
    protected native void close() /*-{
        this.close();
    }-*/;
    
    /**
     * Disconnects the remote socket location with code and reason.
     *
     * @return {void}
     *
     * @public
     * @function
     * @name close
     * @memberOf WebSocket
     */
    protected native void close(int code, String reason) /*-{
        this.close(code, reason);
    }-*/;

    /**
     * Sends text-based data to the remote socket location.
     *
     * @param {String} data   the data payload
     *
     * @return {void}
     *
     * @public
     * @function
     * @name send
     * @memberOf WebSocket
     */
    protected native void send(String data) /*-{
    		this.send(data);
    }-*/;
    
    /**
     * Sends binary-based data to the remote socket location.
     *
     * @param {ByteBuffer} data   the data payload
     *
     * @return {void}
     *
     * @public
     * @function
     * @name send
     * @memberOf WebSocket
     */
    protected native void send(ByteBuffer data) /*-{
    	if (typeof(WebSocketFactory) == "function") {
    		this.send(data);
    	}
    	else {
    		this.send(data.getArrayBuffer(data.remaining()));
    	}
    }-*/;
}
